mt4_fun_num_map = {
"OrderClose": 1
, "SetLevelStyle": 2
, "ArrayFill": 3
, "Comment": 4
, "asin": 5
, "ChartTimeOnDropped": 6
, "ArrayResize": 7
, "sqrt": 8
, "iAD": 9
, "SignalInfoGetDouble": 10
, "CopyTickVolume_002": 11
, "ArrayCopyRates": 12
, "OrderSelect": 13
, "SetIndexArrow": 14
, "iBWMFI": 15
, "AccountName": 16
, "Period": 17
, "TimeYear": 18
, "OrderSwap": 19
, "ChartGetString": 20
, "MathMin": 21
, "GlobalVariableSetOnCondition": 22
, "atan": 23
, "ChartScreenShot": 24
, "iOsMA": 25
, "IsTradeAllowed": 26
, "TimeLocal": 27
, "WindowFirstVisibleBar": 28
, "OrderOpenPrice": 29
, "OrderTicket": 30
, "OrderLots": 31
, "IndicatorSetDouble": 32
, "IsExpertEnabled": 33
, "SignalBaseGetInteger": 34
, "GetPointer": 35
, "SeriesInfoInteger": 36
, "IsLibrariesAllowed": 37
, "IndicatorSetString": 38
, "Day": 39
, "StringSubstr": 40
, "exp": 41
, "ChartGetDouble": 42
, "MathSqrt": 43
, "StringFill": 44
, "StrToDouble": 45
, "ChartIndicatorName": 46
, "StringConcatenate": 47
, "iAO": 48
, "ShortToString": 49
, "AccountInfoDouble": 50
, "iForce": 51
, "ObjectMove": 52
, "IndicatorCounted": 53
, "TerminalClose": 54
, "WindowPriceMax": 55
, "SymbolInfoString": 56
, "CopyLow_002": 57
, "ObjectSetFiboDescription": 58
, "ObjectCreate_002": 59
, "CryptDecode": 60
, "GetTickCount": 61
, "ObjectSetInteger_001": 62
, "ObjectGetTimeByValue": 63
, "iBarShift": 64
, "srand": 65
, "ArrayRange": 66
, "ObjectSetString_002": 67
, "OrderStopLoss": 68
, "SymbolName": 69
, "SignalInfoGetString": 70
, "SignalBaseGetDouble": 71
, "IndicatorShortName": 72
, "MessageBox": 73
, "WindowIsVisible": 74
, "MarketInfo": 75
, "fmin": 76
, "ChartSetInteger": 77
, "CopyLow_003": 78
, "OrderProfit": 79
, "AccountFreeMarginMode": 80
, "MathMod": 81
, "SymbolInfoSessionTrade": 82
, "ObjectFind_001": 83
, "FileFlush": 84
, "ChartSetString": 85
, "CopyClose_001": 86
, "floor": 87
, "WindowXOnDropped": 88
, "AccountFreeMargin": 89
, "FileTell": 90
, "StringAdd": 91
, "CharArrayToString": 92
, "OnChartEvent": 93
, "MQLSetInteger": 94
, "WindowScreenShot": 95
, "ArrayCompare": 96
, "CopyRates_001": 97
, "ChartSymbol": 98
, "FileReadArray": 99
, "ArrayBsearch": 100
, "PeriodSeconds": 101
, "SendMail": 102
, "iRSI": 103
, "TimeMonth": 104
, "Year": 105
, "ObjectDescription": 106
, "ChartSaveTemplate": 107
, "FileReadDatetime": 108
, "iCustom": 109
, "ObjectsTotal_001": 110
, "iBandsOnArray": 111
, "ChartNext": 112
, "FileReadString": 113
, "GlobalVariablesDeleteAll": 114
, "StringToInteger": 115
, "SignalBaseTotal": 116
, "acos": 117
, "iStdDevOnArray": 118
, "ChartClose": 119
, "iEnvelopesOnArray": 120
, "HideTestIndicators": 121
, "ObjectCreate_001": 122
, "MathTan": 123
, "ObjectGetString": 124
, "ColorToString": 125
, "TimeSeconds": 126
, "ArrayFree": 127
, "cos": 128
, "OrdersHistoryTotal": 129
, "SignalUnsubscribe": 130
, "ChartGetInteger": 131
, "AccountLeverage": 132
, "GlobalVariableGet": 133
, "ObjectGetValueByTime": 134
, "TimeDaylightSavings": 135
, "FileFindFirst": 136
, "GlobalVariableSet": 137
, "OrderMagicNumber": 138
, "DayOfYear": 139
, "ObjectSetInteger_002": 140
, "IntegerToString": 141
, "ArrayIsDynamic": 142
, "MathRand": 143
, "OnDeinit": 144
, "AccountCurrency": 145
, "SymbolsTotal": 146
, "StringTrimRight": 147
, "AccountProfit": 148
, "CopyHigh_002": 149
, "FileIsEnding": 150
, "StringLen": 151
, "TextOut": 152
, "FileWriteDouble": 153
, "SetIndexStyle": 154
, "SignalInfoSetDouble": 155
, "SetIndexEmptyValue": 156
, "CharToStr": 157
, "CopyOpen_002": 158
, "iSAR": 159
, "StructToTime": 160
, "iFractals": 161
, "CopyOpen_001": 162
, "StringToColor": 163
, "OrderSend": 164
, "iMA": 165
, "OrderCloseTime": 166
, "Point": 167
, "ArrayCopy": 168
, "ChartApplyTemplate": 169
, "ObjectSet": 170
, "MathPow": 171
, "IsTradeContextBusy": 172
, "TesterStatistics": 173
, "ArraySetAsSeries": 174
, "MathArctan": 175
, "GlobalVariableCheck": 176
, "iOBV": 177
, "OnTick": 178
, "MathSin": 179
, "ObjectSetDouble_001": 180
, "AccountInfoInteger": 181
, "EventChartCustom": 182
, "StrToTime": 183
, "ObjectsDeleteAll_001": 184
, "Hour": 185
, "AccountNumber": 186
, "OrderDelete": 187
, "CheckPointer": 188
, "ObjectName": 189
, "CopyClose_002": 190
, "iBullsPower": 191
, "SymbolInfoTick": 192
, "FileFindNext": 193
, "WindowFind": 194
, "SignalSubscribe": 195
, "FileWriteLong": 196
, "DoubleToString": 197
, "ObjectsDeleteAll_002": 198
, "FileGetInteger": 199
, "TimeDayOfWeek": 200
, "ChartTimePriceToXY": 201
, "SymbolSelect": 202
, "CopyLow_001": 203
, "SignalInfoGetInteger": 204
, "iBearsPower": 205
, "Sleep": 206
, "WindowOnDropped": 207
, "AccountEquity": 208
, "AccountMargin": 209
, "StringCompare": 210
, "FileDelete": 211
, "iIchimoku": 212
, "EventSetTimer": 213
, "SymbolInfoInteger": 214
, "TerminalCompany": 215
, "ArrayInitialize": 216
, "TimeToStr": 217
, "StringFormat": 218
, "IsOptimization": 219
, "ChartSetDouble": 220
, "FileOpen": 221
, "ArrayCopySeries": 222
, "ObjectGetFiboDescription": 223
, "FileWrite": 224
, "ChartID": 225
, "CopyTime_002": 226
, "iLowest": 227
, "ShortArrayToString": 228
, "MathArccos": 229
, "IsVisualMode": 230
, "Print": 231
, "iDeMarker": 232
, "ObjectSetString_001": 233
, "iOpen": 234
, "ChartXYToTimePrice": 235
, "CopyOpen_003": 236
, "WindowRedraw": 237
, "ChartXOnDropped": 238
, "ObjectSetDouble_002": 239
, "SymbolInfoSessionQuote": 240
, "Alert": 241
, "FileReadInteger": 242
, "ChartFirst": 243
, "EnumToString": 244
, "MathSrand": 245
, "CopyHigh_003": 246
, "TerminalInfoInteger": 247
, "CopyClose_003": 248
, "StringInit": 249
, "ResourceCreate": 250
, "ChartWindowOnDropped": 251
, "FileReadLong": 252
, "CopyTime_003": 253
, "OrderTakeProfit": 254
, "iWPR": 255
, "AccountInfoString": 256
, "AccountServer": 257
, "iCCIOnArray": 258
, "WindowHandle": 259
, "ExpertRemove": 260
, "StringSetCharacter": 261
, "EventSetMillisecondTimer": 262
, "FileMove": 263
, "MathLog10": 264
, "MathFloor": 265
, "iEnvelopes": 266
, "ChartRedraw": 267
, "FileSize": 268
, "ArraySort": 269
, "SetIndexShift": 270
, "AccountStopoutMode": 271
, "WindowPriceMin": 272
, "MathIsValidNumber": 273
, "ChartPriceOnDropped": 274
, "TimeDay": 275
, "OrderComment": 276
, "CopyHigh_001": 277
, "ArrayDimension": 278
, "FileWriteFloat": 279
, "iStdDev": 280
, "PlaySound": 281
, "OrderModify": 282
, "iHighest": 283
, "TimeHour": 284
, "CopyTickVolume_003": 285
, "StringGetChar": 286
, "GlobalVariableName": 287
, "FileReadFloat": 288
, "SignalBaseGetString": 289
, "Month": 290
, "TextGetSize": 291
, "fmax": 292
, "ArrayMaximum": 293
, "iClose": 294
, "GlobalVariablesTotal": 295
, "IsConnected": 296
, "iAC": 297
, "round": 298
, "ChartOpen": 299
, "iMACD": 300
, "IndicatorBuffers": 301
, "FileFindClose": 302
, "iLow": 303
, "ZeroMemory": 304
, "StringReplace": 305
, "WindowTimeOnDropped": 306
, "FolderClean": 307
, "OrderExpiration": 308
, "GlobalVariableTemp": 309
, "iMFI": 310
, "StringTrimLeft": 311
, "FolderDelete": 312
, "OrderType": 313
, "OrderOpenTime": 314
, "AccountFreeMarginCheck": 315
, "ObjectDelete_001": 316
, "TerminalInfoDouble": 317
, "DebugBreak": 318
, "SetIndexBuffer": 319
, "SymbolInfoDouble": 320
, "StringToCharArray": 321
, "iMomentumOnArray": 322
, "StringToShortArray": 323
, "AccountCredit": 324
, "FileReadNumber": 325
, "iMomentum": 326
, "WindowPriceOnDropped": 327
, "fabs": 328
, "ObjectsDeleteAll_003": 329
, "MathExp": 330
, "MathLog": 331
, "ResourceFree": 332
, "PrintFormat": 333
, "OnTester": 334
, "OrderPrint": 335
, "FileReadDouble": 336
, "StringFind": 337
, "FolderCreate": 338
, "ChartNavigate": 339
, "DoubleToStr": 340
, "StringToLower": 341
, "FileSeek": 342
, "ObjectGetDouble": 343
, "iBars": 344
, "ChartIndicatorsTotal": 345
, "ChartYOnDropped": 346
, "FileReadStruct": 347
, "IsTesting": 348
, "iAlligator": 349
, "TimeGMTOffset": 350
, "OrderClosePrice": 351
, "MathMax": 352
, "log": 353
, "sin": 354
, "IsDemo": 355
, "SignalBaseSelect": 356
, "Client_Registration": 357
, "MQLInfoInteger": 358
, "WindowYOnDropped": 359
, "ResourceReadImage": 360
, "ObjectGet": 361
, "StringToDouble": 362
, "TimeToStruct": 363
, "WindowExpertName": 364
, "CopyRates_003": 365
, "IndicatorSetInteger": 366
, "TerminalInfoString": 367
, "DayOfWeek": 368
, "iADX": 369
, "Heartbeat": 370
, "ObjectGetShiftByValue": 371
, "ResetLastError": 372
, "MathAbs": 373
, "StringToTime": 374
, "MathArcsin": 375
, "SetIndexLabel": 376
, "ChartWindowFind": 377
, "iCCI": 378
, "WindowsTotal": 379
, "OrderCloseBy": 380
, "StringBufferLen": 381
, "Bars_001": 382
, "rand": 383
, "iRSIOnArray": 384
, "tan": 385
, "CopyTime_001": 386
, "Bars_002": 387
, "FileIsExist": 388
, "AccountCompany": 389
, "OrdersTotal": 390
, "MathCeil": 391
, "FileCopy": 392
, "log10": 393
, "CryptEncode": 394
, "GlobalVariableTime": 395
, "iATR": 396
, "iHigh": 397
, "OrderSymbol": 398
, "StringToUpper": 399
, "iMAOnArray": 400
, "FileIsLineEnding": 401
, "StringSplit": 402
, "NormalizeDouble": 403
, "ChartIndicatorDelete": 404
, "ObjectType": 405
, "MathRound": 406
, "TextSetFont": 407
, "TimeCurrent": 408
, "SetIndexDrawBegin": 409
, "ceil": 410
, "GlobalVariablesFlush": 411
, "OrderCommission": 412
, "IsDllsAllowed": 413
, "iVolume": 414
, "SendFTP": 415
, "ArrayIsSeries": 416
, "TerminalPath": 417
, "Digits": 418
, "iTime": 419
, "IsStopped": 420
, "GlobalVariableDel": 421
, "MQLInfoString": 422
, "AccountStopoutLevel": 423
, "iGator": 424
, "WebRequest": 425
, "ChartPeriod": 426
, "FileWriteStruct": 427
, "IndicatorDigits": 428
, "ChartSetSymbolPeriod": 429
, "GetLastError": 430
, "FileReadBool": 431
, "ObjectGetInteger": 432
, "ObjectSetText": 433
, "ObjectsTotal_002": 434
, "MathCos": 435
, "TimeMinute": 436
, "ArrayGetAsSeries": 437
, "UninitializeReason": 438
, "iBands": 439
, "TimeDayOfYear": 440
, "EventKillTimer": 441
, "FileOpenHistory": 442
, "ColorToARGB": 443
, "ResourceSave": 444
, "SendNotification": 445
, "ArraySize": 446
, "pow": 447
, "CharToString": 448
, "CopyTickVolume_001": 449
, "OnTimer": 450
, "CopyRates_002": 451
, "SetLevelValue": 452
, "FileWriteInteger": 453
, "StrToInteger": 454
, "ObjectGetValueByShift": 455
, "Seconds": 456
, "Symbol": 457
, "FileWriteString": 458
, "StringSetChar": 459
, "ObjectFind_002": 460
, "fmod": 461
, "WindowBarsPerChart": 462
, "AccountBalance": 463
, "iStochastic": 464
, "SignalInfoSetInteger": 465
, "ObjectDelete_002": 466
, "iRVI": 467
, "TerminalName": 468
, "FileClose": 469
, "TimeToString": 470
, "Minute": 471
, "StringGetCharacter": 472
, "TimeGMT": 473
, "FileWriteArray": 474
, "RefreshRates": 475
, "OnInit": 476
, "ArrayMinimum": 477
}
